@@ -259,6 +259,7 @@ class DataItem(ABC):
         check (bool): check value (default: True)
     """
 
+    type = type
     count = 0
 
     def __init__(
@@ -273,9 +274,9 @@ class DataItem(ABC):
         self._name: str | None = None
         self._default = default
         self._help = help
-        self._props: dict[Any, Any] = (
-            {}
-        )  # a dict realm->dict containing realm-specific properties
+        self._props: dict[
+            Any, Any
+        ] = {}  # a dict realm->dict containing realm-specific properties
         self.set_prop("display", col=0, colspan=None, row=None, label=label)
         self.set_prop("data", check_value=check)
 
@@ -456,6 +457,14 @@ class DataItem(ABC):
         value = self.from_string(string_value)
         self.__set__(instance, value)
 
+    def get_default(self) -> Any:
+        """Return data item's default value
+
+        Returns:
+            Any: default value
+        """
+        return self._default
+
     def set_default(self, instance: DataSet) -> None:
         """Set data item's value to default
 
@@ -993,6 +1002,7 @@ class DataSetMeta(type):
                 items[attrname] = value
         items_list = list(items.values())
         items_list.sort(key=lambda x: x._order)
+
         dct["_items"] = items_list
         return type.__new__(cls, name, bases, dct)
 
@@ -1012,7 +1022,7 @@ class DataSet(metaclass=DataSetMeta):
         icon (str): icon filename as in image search paths
     """
 
-    _items: list[DataItem]
+    _items: list[DataItem] = []
     __metaclass__ = DataSetMeta  # keep it even with Python 3 (see DataSetMeta)
 
     def __init__(
@@ -1052,7 +1062,7 @@ class DataSet(metaclass=DataSetMeta):
         return list(filter(lambda s: not s.get_name().startswith("_"), result_items))
 
     @classmethod
-    def create(cls, **kwargs) -> DataSet:
+    def create(cls: type[AnyDataSet], **kwargs) -> AnyDataSet:
         """Create a new instance of the DataSet class
 
         Args:
@@ -1062,10 +1072,13 @@ class DataSet(metaclass=DataSetMeta):
             DataSet instance
         """  # noqa
         instance = cls()
-        for item in instance._items:
-            name = item._name
-            if name in kwargs:
-                setattr(instance, name, kwargs[name])
+        for name in kwargs:
+            for item in instance._items:
+                if item._name == name:
+                    setattr(instance, name, kwargs[name])
+                    break
+            else:
+                raise AttributeError(f"Unknown attribute {name}")
         return instance
 
     def _get_translation(self):
