@@ -25,7 +25,7 @@ from abc import abstractmethod
 from collections.abc import Callable
 from typing import TYPE_CHECKING, Any, Protocol
 
-import numpy
+import numpy as np
 from qtpy.compat import getexistingdirectory
 from qtpy.QtCore import QSize, Qt
 from qtpy.QtGui import QColor, QIcon, QPixmap
@@ -462,6 +462,7 @@ class TextEditWidget(AbstractDataSetWidget):
         else:
             self.edit.setStyleSheet("")
         self.update(value)
+        _display_callback(self, value)
         self.notify_value_change()
 
     def update(self, value: Any) -> Any:
@@ -552,6 +553,7 @@ class CheckBoxWidget(AbstractDataSetWidget):
         layout.addWidget(self.group, row, widget_column, row_span, column_span)
 
     def state_changed(self, state: bool) -> None:
+        _display_callback(self, state)
         self.notify_value_change()
         if self.store:
             self.do_store(state)
@@ -762,7 +764,7 @@ class ColorWidget(HLayoutMixin, LineEditWidget):
             bitmap.fill(color)
             icon = QIcon(bitmap)
         else:
-            icon = get_icon("not_found")
+            icon = get_icon("not_found.png")
         self.button.setIcon(icon)
 
     def select_color(self) -> None:
@@ -1018,6 +1020,7 @@ class ChoiceWidget(AbstractDataSetWidget):
         """
         if self.is_radio:
             for button in self._buttons:
+                button.hide()
                 button.toggled.disconnect(self.index_changed)  # type:ignore
                 self.vbox.removeWidget(button)
                 button.deleteLater()
@@ -1246,7 +1249,7 @@ class FloatArrayWidget(AbstractDataSetWidget):
         self.layout.addLayout(self.max_line, 2, 0)
 
         edit_button.clicked.connect(self.edit_array)  # type:ignore
-        self.arr = numpy.array([])  # le tableau si il a été modifié
+        self.arr = np.array([])  # le tableau si il a été modifié
         self.instance = None
 
         self.dtype_line, self.dtype_label = get_image_layout("dtype.png", "")
@@ -1273,12 +1276,12 @@ class FloatArrayWidget(AbstractDataSetWidget):
 
     def get(self) -> None:
         """Update widget contents from data item value"""
-        self.arr = numpy.array(self.item.get(), copy=False)
+        self.arr = np.asarray(self.item.get())
         if self.item.get_prop_value("display", "transpose"):
             self.arr = self.arr.T
         self.update(self.arr)
 
-    def update(self, arr: numpy.ndarray) -> None:
+    def update(self, arr: np.ndarray) -> None:
         shape = arr.shape
         if len(shape) == 1:
             shape = (1,) + shape
@@ -1287,7 +1290,7 @@ class FloatArrayWidget(AbstractDataSetWidget):
 
         format = self.item.get_prop_value("display", "format")
         minmax = self.item.get_prop_value("display", "minmax")
-        real_arr = numpy.real(arr)
+        real_arr = np.real(arr)
         try:
             if minmax == "all":
                 mint = format % real_arr.min()
@@ -1321,7 +1324,7 @@ class FloatArrayWidget(AbstractDataSetWidget):
             value = self.value()
         self.item.set(value)
 
-    def value(self) -> numpy.ndarray:
+    def value(self) -> np.ndarray:
         """Returns the widget's current value
 
         Returns:
