@@ -59,9 +59,10 @@ import os
 import os.path as osp
 import sys
 import time
+import warnings
 from contextlib import contextmanager
 from datetime import datetime
-from typing import TYPE_CHECKING, Generator, Iterable
+from typing import TYPE_CHECKING, Generator, Iterable, Literal
 
 from qtpy import QtCore as QC
 from qtpy import QtGui as QG
@@ -77,16 +78,166 @@ if TYPE_CHECKING:
     from collections.abc import Callable
 
 
+ENV_COLOR_MODE = "QT_COLOR_MODE"
+COLOR_MODES = LIGHT, DARK, AUTO = "light", "dark", "auto"
+CURRENT_THEME = None
+
+
+def set_dark_mode(state: bool) -> None:
+    """Set dark mode for Qt application
+    (deprecated, use `set_color_mode` instead)
+
+    Args:
+        state: True to enable dark mode
+    """
+    mode = DARK if state else LIGHT
+    warnings.warn(
+        f"`set_dark_mode` is deprecated and will be removed in a future version. "
+        f"Use `set_color_mode('{mode}')` instead.",
+        DeprecationWarning,
+    )
+    set_color_mode(mode)
+
+
 def is_dark_mode() -> bool:
     """Return True if current color mode is dark mode
+    (deprecated, use `is_dark_theme` instead)
 
     Returns:
-        bool: True if dark mode is enabled
+        True if dark mode is enabled
     """
-    try:
-        return os.environ["QT_COLOR_MODE"].lower() == "dark"
-    except KeyError:
-        return darkdetect.isDark()
+    warnings.warn(
+        "`is_dark_mode` is deprecated and will be removed in a future version. "
+        "Use `is_dark_theme` instead.",
+        DeprecationWarning,
+    )
+    return is_dark_theme()
+
+
+def get_color_theme() -> Literal["light", "dark"]:
+    """Get color theme.
+
+    Color theme value is updated only once per session because the query to the system
+    may be expensive depending on the platform. It is updated when the color mode is
+    set to 'auto' using `set_color_mode('auto')`.
+
+    Returns:
+        Color theme ('light' or 'dark')
+    """
+    global CURRENT_THEME
+    mode = get_color_mode()
+    if mode == AUTO:
+        theme = DARK if darkdetect.isDark() else LIGHT
+    else:
+        theme = mode
+    CURRENT_THEME = theme
+    return theme
+
+
+def is_dark_theme() -> bool:
+    """Return True if current color mode is dark mode.
+
+    Color theme value is updated only once per session because the query to the system
+    may be expensive depending on the platform. It is updated when the color mode is
+    set to 'auto' using `set_color_mode('auto')`.
+
+    Returns:
+        True if dark mode is enabled
+    """
+    return get_color_theme() == DARK
+
+
+def get_color_mode() -> Literal["light", "dark", "auto"]:
+    """Get color mode
+
+    Returns:
+        Color mode ('light', 'dark' or 'auto')
+    """
+    mode = os.environ.get(ENV_COLOR_MODE, AUTO).lower()
+    if mode not in COLOR_MODES:
+        # Just show a warning, the mode will be set to 'auto':
+        warnings.warn(
+            f"Invalid color mode: {mode} (expected {COLOR_MODES}). "
+            "Using 'auto' instead.",
+            UserWarning,
+        )
+        mode = AUTO
+    return mode
+
+
+DEFAULT_STYLES = None
+
+
+def get_background_color() -> QG.QColor:
+    """Get current theme background color"""
+    return QW.QApplication.instance().palette().color(QG.QPalette.Base)
+
+
+def get_foreground_color() -> QG.QColor:
+    """Get current theme foreground color"""
+    return QW.QApplication.instance().palette().color(QG.QPalette.Text)
+
+
+def set_color_mode(mode: Literal["light", "dark", "auto"] | None = None):
+    """Set color mode.
+
+    Args:
+        mode: Color mode ('light', 'dark' or 'auto'). If 'auto', the system color mode
+        is used. If None, the `QT_COLOR_MODE` environment variable is used.
+    """
+    global DEFAULT_STYLES, CURRENT_THEME
+
+    CURRENT_THEME = None
+
+    if mode is not None:
+        assert (
+            mode in COLOR_MODES
+        ), f"Invalid color mode: {mode} (expected {COLOR_MODES})"
+        os.environ[ENV_COLOR_MODE] = mode
+
+    app = QW.QApplication.instance()
+
+    if DEFAULT_STYLES is None:
+        # Store default palette to be able to restore it:
+        DEFAULT_STYLES = app.style().objectName(), app.palette(), app.styleSheet()
+
+    if is_dark_theme():
+        app.setStyle(QW.QStyleFactory.create("Fusion"))
+        dark_palette = QG.QPalette()
+        dark_color = QG.QColor(50, 50, 50)
+        disabled_color = QG.QColor(127, 127, 127)
+        dpsc = dark_palette.setColor
+        dpsc(QG.QPalette.Window, dark_color)
+        dpsc(QG.QPalette.WindowText, QC.Qt.white)
+        dpsc(QG.QPalette.Base, QG.QColor(31, 31, 31))
+        dpsc(QG.QPalette.AlternateBase, dark_color)
+        dpsc(QG.QPalette.ToolTipBase, QC.Qt.white)
+        dpsc(QG.QPalette.ToolTipText, QC.Qt.white)
+        dpsc(QG.QPalette.Text, QC.Qt.white)
+        dpsc(QG.QPalette.Disabled, QG.QPalette.Text, disabled_color)
+        dpsc(QG.QPalette.Button, dark_color)
+        dpsc(QG.QPalette.ButtonText, QC.Qt.white)
+        dpsc(QG.QPalette.Disabled, QG.QPalette.ButtonText, disabled_color)
+        dpsc(QG.QPalette.BrightText, QC.Qt.red)
+        dpsc(QG.QPalette.Link, QG.QColor(42, 130, 218))
+        dpsc(QG.QPalette.Highlight, QG.QColor(42, 130, 218))
+        dpsc(QG.QPalette.HighlightedText, QC.Qt.black)
+        dpsc(QG.QPalette.Disabled, QG.QPalette.HighlightedText, disabled_color)
+        app.setPalette(dark_palette)
+        app.setStyleSheet(
+            "QToolTip { "
+            "color: white; background-color: #2a82da; border: 1px solid white;"
+            " }"
+        )
+    elif DEFAULT_STYLES is not None:
+        style, palette, stylesheet = DEFAULT_STYLES
+        app.setStyle(QW.QStyleFactory.create(style))
+        app.setPalette(palette)
+        app.setStyleSheet(stylesheet)
+
+    # Iterate over all top-level widgets:
+    for widget in QW.QApplication.instance().topLevelWidgets():
+        win32_fix_title_bar_background(widget)
 
 
 def win32_fix_title_bar_background(widget: QW.QWidget) -> None:
@@ -95,7 +246,7 @@ def win32_fix_title_bar_background(widget: QW.QWidget) -> None:
     Args:
         widget (QW.QWidget): Widget to fix
     """
-    if os.name != "nt" or not is_dark_mode() or sys.maxsize == 2**31 - 1:
+    if os.name != "nt" or sys.maxsize == 2**31 - 1:
         return
 
     import ctypes
@@ -117,10 +268,15 @@ def win32_fix_title_bar_background(widget: QW.QWidget) -> None:
         ]
 
     accent = ACCENTPOLICY()
-    accent.AccentState = 1  # Default window Blur #ACCENT_ENABLE_BLURBEHIND
-
     data = WINDOWCOMPOSITIONATTRIBDATA()
-    data.Attribute = 26  # WCA_USEDARKMODECOLORS
+
+    if is_dark_theme():
+        accent.AccentState = 3  # ACCENT_ENABLE_ACRYLICBLURBEHIND
+        data.Attribute = 26  # WCA_USEDARKMODECOLORS
+    else:
+        accent.AccentState = 0  # ACCENT_DISABLED
+        data.Attribute = 19  # WCA_ACCENT_POLICY
+
     data.SizeOfData = ctypes.sizeof(accent)
     data.Data = ctypes.cast(ctypes.pointer(accent), ctypes.POINTER(ctypes.c_int))
 
@@ -129,6 +285,17 @@ def win32_fix_title_bar_background(widget: QW.QWidget) -> None:
     set_win_cpa.restype = ctypes.c_int
     set_win_cpa(int(widget.winId()), data)
 
+    if not is_dark_theme():
+        # Setting dark mode attribute to False (0) to ensure the default light mode
+        attribute_value = ctypes.c_int(0)
+        hwnd = wintypes.HWND(int(widget.winId()))
+        ctypes.windll.dwmapi.DwmSetWindowAttribute(
+            hwnd,
+            20,  # DWMWA_USE_IMMERSIVE_DARK_MODE, # Dark mode attribute
+            ctypes.byref(attribute_value),
+            ctypes.sizeof(attribute_value),
+        )
+
 
 def create_action(
     parent: QW.QWidget | None,
