@@ -10,9 +10,12 @@
 guidata.widgets.collectionseditor
 =================================
 
-This package provides a Collections (i.e. dictionary, list and tuple) editor widget and dialog.
+This package provides a Collections (i.e. dictionary, list and tuple) editor widget
+and dialog.
 
 .. autoclass:: CollectionsEditor
+    :show-inheritance:
+    :members:
 
 """
 
@@ -31,7 +34,31 @@ import re
 import sys
 import warnings
 
-import PIL.Image
+try:
+    from PIL import Image as PILImage
+except ImportError:
+    PILImage = None
+from qtpy.compat import getsavefilename
+from qtpy.QtCore import QAbstractTableModel, QDateTime, QModelIndex, Qt, Signal, Slot
+from qtpy.QtGui import QColor, QKeySequence
+from qtpy.QtWidgets import (
+    QAbstractItemDelegate,
+    QApplication,
+    QDateEdit,
+    QDateTimeEdit,
+    QDialog,
+    QHBoxLayout,
+    QInputDialog,
+    QItemDelegate,
+    QLineEdit,
+    QMenu,
+    QMessageBox,
+    QPushButton,
+    QTableView,
+    QVBoxLayout,
+    QWidget,
+)
+
 from guidata.config import CONF, _
 from guidata.configtools import get_font, get_icon
 from guidata.qthelpers import (
@@ -40,7 +67,7 @@ from guidata.qthelpers import (
     mimedata2url,
     win32_fix_title_bar_background,
 )
-from guidata.utils import getcwd_or_home
+from guidata.utils.misc import getcwd_or_home
 from guidata.widgets.importwizard import ImportWizard
 from guidata.widgets.nsview import (
     DataFrame,
@@ -66,26 +93,6 @@ from guidata.widgets.nsview import (
     value_to_display,
 )
 from guidata.widgets.texteditor import TextEditor
-from qtpy.compat import getsavefilename
-from qtpy.QtCore import QAbstractTableModel, QDateTime, QModelIndex, Qt, Signal, Slot
-from qtpy.QtGui import QColor, QKeySequence
-from qtpy.QtWidgets import (
-    QAbstractItemDelegate,
-    QApplication,
-    QDateEdit,
-    QDateTimeEdit,
-    QDialog,
-    QHBoxLayout,
-    QInputDialog,
-    QItemDelegate,
-    QLineEdit,
-    QMenu,
-    QMessageBox,
-    QPushButton,
-    QTableView,
-    QVBoxLayout,
-    QWidget,
-)
 
 if ndarray is not FakeObject:
     from guidata.widgets.arrayeditor import ArrayEditor
@@ -109,7 +116,11 @@ def fix_reference_name(name, blacklist=None):
     if not name:
         name = "data"
     if blacklist is not None and name in blacklist:
-        get_new_name = lambda index: name + ("%03d" % index)
+
+        def get_new_name(index):
+            """Generate new name"""
+            return name + ("%03d" % index)
+
         index = 0
         while get_new_name(index) in blacklist:
             index += 1
@@ -117,7 +128,7 @@ def fix_reference_name(name, blacklist=None):
     return name
 
 
-class ProxyObject(object):
+class ProxyObject:
     """Dictionary proxy to an unknown object."""
 
     def __init__(self, obj):
@@ -278,21 +289,21 @@ class ReadOnlyCollectionsModel(QAbstractTableModel):
             self.types = sort_against(self.types, self.keys, reverse)
             try:
                 self.keys.sort(reverse=reverse)
-            except:
+            except Exception:  # pylint: disable=broad-except
                 pass
         elif column == 1:
             self.keys[: self.rows_loaded] = sort_against(self.keys, self.types, reverse)
             self.sizes = sort_against(self.sizes, self.types, reverse)
             try:
                 self.types.sort(reverse=reverse)
-            except:
+            except Exception:  # pylint: disable=broad-except
                 pass
         elif column == 2:
             self.keys[: self.rows_loaded] = sort_against(self.keys, self.sizes, reverse)
             self.types = sort_against(self.types, self.sizes, reverse)
             try:
                 self.sizes.sort(reverse=reverse)
-            except:
+            except Exception:  # pylint: disable=broad-except
                 pass
         elif column == 3:
             values = [self._data[key] for key in self.keys]
@@ -466,8 +477,6 @@ class CollectionsModel(ReadOnlyCollectionsModel):
 class CollectionsDelegate(QItemDelegate):
     """CollectionsEditor Item Delegate"""
 
-    sig_free_memory = Signal()
-
     def __init__(self, parent=None):
         QItemDelegate.__init__(self, parent)
         self._editors = {}  # keep references on opened editors
@@ -505,7 +514,7 @@ class CollectionsDelegate(QItemDelegate):
         try:
             val_size = index.model().sizes[index.row()]
             val_type = index.model().types[index.row()]
-        except:
+        except Exception:  # pylint: disable=broad-except
             return False
         if val_type in ["list", "tuple", "dict"] and int(val_size) > 1e5:
             return True
@@ -537,7 +546,7 @@ class CollectionsDelegate(QItemDelegate):
                 self.parent(),
                 _("Error"),
                 _(
-                    "Spyder was unable to retrieve the value of "
+                    "Unable to retrieve the value of "
                     "this variable from the console.<br><br>"
                     "The error mesage was:<br>"
                     "<i>%s</i>"
@@ -580,7 +589,11 @@ class CollectionsDelegate(QItemDelegate):
             editor = ArrayEditor(parent=parent)
             if not editor.setup_and_check(arr, title=key, readonly=readonly):
                 return
-            conv_func = lambda arr: PIL.Image.fromarray(arr, mode=value.mode)
+
+            def conv_func(arr):
+                """Conversion function"""
+                return PILImage.fromarray(arr, mode=value.mode)
+
             self.create_dialog(
                 editor,
                 dict(
@@ -689,7 +702,8 @@ class CollectionsDelegate(QItemDelegate):
             conv_func = data.get("conv", lambda v: v)
             self.set_value(index, conv_func(value))
         self._editors.pop(editor_id)
-        self.free_memory()
+        editor = self.sender()
+        editor.deleteLater()
 
     def editor_rejected(self, editor_id):
         """
@@ -697,14 +711,8 @@ class CollectionsDelegate(QItemDelegate):
         :param editor_id:
         """
         self._editors.pop(editor_id)
-        self.free_memory()
-
-    def free_memory(self):
-        """Free memory after closing an editor."""
-        try:
-            self.sig_free_memory.emit()
-        except RuntimeError:
-            pass
+        editor = self.sender()
+        editor.deleteLater()
 
     def commitAndCloseEditor(self):
         """Overriding method commitAndCloseEditor"""
@@ -727,7 +735,7 @@ class CollectionsDelegate(QItemDelegate):
             if isinstance(value, bytes):
                 try:
                     value = str(value, "utf8")
-                except:
+                except Exception:  # pylint: disable=broad-except
                     pass
             if not isinstance(value, str):
                 value = repr(value)
@@ -791,7 +799,6 @@ class BaseTableView(QTableView):
     sig_option_changed = Signal(str, object)
     sig_files_dropped = Signal(list)
     redirect_stdio = Signal(bool)
-    sig_free_memory = Signal()
 
     def __init__(self, parent):
         QTableView.__init__(self, parent)
@@ -1208,21 +1215,21 @@ class BaseTableView(QTableView):
 
     def __prepare_plot(self):
         try:
-            import guiqwt.pyplot  # analysis:ignore
+            import plotpy.pyplot  # analysis:ignore
 
             return True
-        except:
+        except Exception:  # pylint: disable=broad-except
             try:
                 if "matplotlib" not in sys.modules:
                     import matplotlib
 
                     matplotlib.use("Qt5Agg")
                 return True
-            except:
+            except Exception:  # pylint: disable=broad-except
                 QMessageBox.warning(
                     self,
                     _("Import error"),
-                    _("Please install <b>matplotlib</b>" " or <b>guiqwt</b>."),
+                    _("Please install <b>PlotPy</b>" " or <b>matplotlib</b>."),
                 )
 
     def plot_item(self, funcname):
@@ -1300,7 +1307,7 @@ class BaseTableView(QTableView):
                 output = io.BytesIO()
                 try:
                     np_savetxt(output, obj, delimiter="\t")
-                except:
+                except Exception:  # pylint: disable=broad-except
                     QMessageBox.warning(
                         self,
                         _("Warning"),
@@ -1313,7 +1320,7 @@ class BaseTableView(QTableView):
                 output = io.StringIO()
                 try:
                     obj.to_csv(output, sep="\t", index=True, header=True)
-                except Exception:
+                except Exception:  # pylint: disable=broad-except
                     QMessageBox.warning(
                         self,
                         _("Warning"),
@@ -1342,7 +1349,7 @@ class BaseTableView(QTableView):
             contents_title=_("Clipboard contents"),
             varname=fix_reference_name("data", blacklist=list(data.keys())),
         )
-        if editor.exec_():
+        if editor.exec():
             var_name, clip_data = editor.get_data()
             self.new_value(var_name, clip_data)
 
@@ -1446,7 +1453,7 @@ class CollectionsEditorTableView(BaseTableView):
     def plot(self, key, funcname):
         """Plot item"""
         data = self.model.get_data()
-        import guiqwt.pyplot as plt
+        import plotpy.pyplot as plt
 
         plt.figure()
         getattr(plt, funcname)(data[key])
@@ -1455,7 +1462,7 @@ class CollectionsEditorTableView(BaseTableView):
     def imshow(self, key):
         """Show item's image"""
         data = self.model.get_data()
-        import guiqwt.pyplot as plt
+        import plotpy.pyplot as plt
 
         plt.figure()
         plt.imshow(data[key])
@@ -1529,7 +1536,7 @@ class CollectionsEditor(QDialog):
     def setup(self, data, title="", readonly=False, width=650, icon=None, parent=None):
         """Setup editor."""
         if isinstance(data, dict):
-            # dictionnary
+            # dictionary
             self.data_copy = data.copy()
             datalen = len(data)
         elif isinstance(data, (tuple, list)):
@@ -1605,15 +1612,3 @@ class CollectionsEditor(QDialog):
         # It is import to avoid accessing Qt C++ object as it has probably
         # already been destroyed, due to the Qt.WA_DeleteOnClose attribute
         return self.data_copy
-
-
-class DictEditor(CollectionsEditor):
-    """ """
-
-    def __init__(self, parent=None):
-        warnings.warn(
-            "`DictEditor` has been renamed to `CollectionsEditor` in "
-            "Spyder 3. Please use `CollectionsEditor` instead",
-            RuntimeWarning,
-        )
-        CollectionsEditor.__init__(self, parent)
