@@ -11,7 +11,6 @@
 # pylint: disable=R0911
 # pylint: disable=R0201
 
-
 import os
 import re
 import sys
@@ -21,7 +20,6 @@ from qtpy.QtCore import QEvent, QEventLoop, QPoint, Qt, Signal, Slot
 from qtpy.QtGui import (
     QClipboard,
     QColor,
-    QFont,
     QMouseEvent,
     QPalette,
     QTextCharFormat,
@@ -40,6 +38,7 @@ from qtpy.QtWidgets import (
     QToolTip,
 )
 
+from guidata import qthelpers as qth
 from guidata.config import CONF
 from guidata.configtools import get_font, get_icon
 from guidata.widgets.console.calltip import CallTipWidget
@@ -367,8 +366,9 @@ class TextEditBaseWidget(QPlainTextEdit, BaseEditMixin):
         background color and caret (text cursor) color
         """
         palette = QPalette()
-        palette.setColor(QPalette.Base, background)
+        # palette.setColor(QPalette.Base, background)
         palette.setColor(QPalette.Text, foreground)
+        palette.setColor(QPalette.Background, background)
         self.setPalette(palette)
 
         # Set the right background color when changing color schemes
@@ -652,7 +652,7 @@ class TextEditBaseWidget(QPlainTextEdit, BaseEditMixin):
 
         :param event:
         """
-        text, key = event.text(), event.key()
+        _text, key = event.text(), event.key()
         ctrl = event.modifiers() & Qt.ControlModifier
         meta = event.modifiers() & Qt.MetaModifier
         # Use our own copy method for {Ctrl,Cmd}+C to avoid Qt
@@ -1423,15 +1423,14 @@ class QtANSIEscapeCodeHandler(ANSIEscapeCodeHandler):
 
 
 def inverse_color(color):
-    """
-
-    :param color:
-    """
-    color.setHsv(color.hue(), color.saturation(), 255 - color.value())
+    """Inverse color"""
+    inv_color = QColor()
+    inv_color.setHsv(color.hue(), color.saturation(), 255 - color.value())
+    return inv_color
 
 
 class ConsoleFontStyle(object):
-    """ """
+    """Console font style management"""
 
     def __init__(self, foregroundcolor, backgroundcolor, bold, italic, underline):
         self.foregroundcolor = foregroundcolor
@@ -1441,23 +1440,23 @@ class ConsoleFontStyle(object):
         self.underline = underline
         self.format = None
 
-    def apply_style(self, font, light_background, is_default):
-        """
+    def apply_style(self, font, is_default):
+        """Apply style to font
 
-        :param font:
-        :param light_background:
-        :param is_default:
+        Args:
+            font: QFont
+            is_default: Default is standard text (not error, link, etc.)
         """
         self.format = QTextCharFormat()
         self.format.setFont(font)
-        foreground = QColor(self.foregroundcolor)
-        if not light_background and is_default:
-            inverse_color(foreground)
-        self.format.setForeground(foreground)
-        background = QColor(self.backgroundcolor)
-        if not light_background:
-            inverse_color(background)
-        self.format.setBackground(background)
+        fg_color = QColor(self.foregroundcolor)
+        if is_default:
+            self.format.setForeground(
+                inverse_color(fg_color) if qth.is_dark_theme() else fg_color
+            )
+        else:
+            self.format.setForeground(fg_color)
+        self.format.setBackground(qth.get_background_color())
         font = self.format.font()
         font.setBold(self.bold)
         font.setItalic(self.italic)
@@ -1476,9 +1475,6 @@ class ConsoleBaseWidget(TextEditBaseWidget):
 
     def __init__(self, parent=None):
         TextEditBaseWidget.__init__(self, parent)
-
-        self.light_background = True
-
         self.setMaximumBlockCount(300)
 
         # ANSI escape code handler
@@ -1525,23 +1521,41 @@ class ConsoleBaseWidget(TextEditBaseWidget):
             self.traceback_link_style,
             self.prompt_style,
         )
-        self.set_pythonshell_font()
+        self.update_color_mode()
         self.setMouseTracking(True)
 
-    def set_light_background(self, state):
-        """
+    def update_color_mode(self):
+        """Update color mode according to the current theme"""
+        self.set_light_background(not qth.is_dark_theme())
 
-        :param state:
+    def set_light_background(self, state):
+        """Set light background state
+
+        Args:
+            state: bool
         """
-        self.light_background = state
-        if state:
-            self.set_palette(
-                background=QColor(Qt.white), foreground=QColor(Qt.darkGray)
-            )
-        else:
-            self.set_palette(
-                background=QColor(Qt.black), foreground=QColor(Qt.lightGray)
-            )
+        default_fg_color = QColor(self.default_style.foregroundcolor)
+        if not state:
+            default_fg_color = inverse_color(default_fg_color)
+        bg_color = qth.get_background_color()
+
+        cursor = self.textCursor()
+        cursor.movePosition(QTextCursor.Start)
+        while not cursor.atEnd():
+            cursor.setPosition(cursor.block().position())
+            cursor.movePosition(QTextCursor.EndOfBlock, QTextCursor.KeepAnchor)
+            charformat = cursor.charFormat()
+            if charformat.background() == bg_color:
+                break
+            charformat.setBackground(bg_color)
+            col = charformat.foreground().color()
+            if col.red() == col.green() and col.green() == col.blue():
+                # Default style
+                charformat.setForeground(default_fg_color)
+            cursor.setCharFormat(charformat)
+            cursor.movePosition(QTextCursor.NextBlock)
+
+        self.set_palette(background=bg_color, foreground=qth.get_foreground_color())
         self.ansi_handler.set_light_background(state)
         self.set_pythonshell_font()
 
@@ -1609,26 +1623,16 @@ class ConsoleBaseWidget(TextEditBaseWidget):
                     pass
                 self.default_style.format = self.ansi_handler.get_format()
             insert_text_to(cursor, text[last_end:], self.default_style.format)
-        #            # Slower alternative:
-        #            segments = self.COLOR_PATTERN.split(text)
-        #            cursor.insertText(segments.pop(0), self.default_style.format)
-        #            if segments:
-        #                for ansi_tags, text in zip(segments[::2], segments[1::2]):
-        #                    for ansi_tag in ansi_tags.split(';'):
-        #                        self.ansi_handler.set_code(int(ansi_tag))
-        #                    self.default_style.format = self.ansi_handler.get_format()
-        #                    cursor.insertText(text, self.default_style.format)
         self.set_cursor_position("eof")
         self.setCurrentCharFormat(self.default_style.format)
 
     def set_pythonshell_font(self, font=None):
         """Python Shell only"""
         if font is None:
-            font = QFont()
+            if self.default_style.format is None:
+                font = self.font()
+            else:
+                font = self.default_style.format.font()
         for style in self.font_styles:
-            style.apply_style(
-                font=font,
-                light_background=self.light_background,
-                is_default=style is self.default_style,
-            )
+            style.apply_style(font=font, is_default=style is self.default_style)
         self.ansi_handler.set_base_format(self.default_style.format)
