@@ -15,28 +15,20 @@ IPython console plugin.
 import os
 import os.path as osp
 import re
-import sre_constants
 import textwrap
 from xml.sax.saxutils import escape
 
-from qtpy.QtWidgets import (
-    QApplication,
-    QToolTip,
-)
-from qtpy.QtGui import (
-    QCursor,
-    QTextCursor,
-    QTextDocument,
-)
-from qtpy.QtCore import Qt, QPoint, QRegularExpression
+from qtpy.QtCore import QPoint, QRegularExpression, Qt
+from qtpy.QtGui import QCursor, QTextCursor, QTextDocument
+from qtpy.QtWidgets import QApplication, QToolTip
 
+from guidata.config import _
+from guidata.utils import encoding
 from guidata.widgets.console.dochelpers import (
     getargspecfromtext,
     getobj,
     getsignaturefromtext,
 )
-from guidata import encoding
-from guidata.config import _
 
 # Order is important:
 EOL_CHARS = (("\r\n", "nt"), ("\n", "posix"), ("\r", "mac"))
@@ -322,7 +314,7 @@ class BaseEditMixin(object):
         if text and not all_text:
             while text.endswith("\n"):
                 text = text[:-1]
-            while text.endswith(u"\u2029"):
+            while text.endswith("\u2029"):
                 text = text[:-1]
         return text
 
@@ -421,7 +413,7 @@ class BaseEditMixin(object):
         """Return line at *coordinates* (QPoint)"""
         cursor = self.cursorForPosition(coordinates)
         cursor.select(QTextCursor.BlockUnderCursor)
-        return str(cursor.selectedText()).replace(u"\u2029", "")
+        return str(cursor.selectedText()).replace("\u2029", "")
 
     def get_word_at(self, coordinates):
         """Return word at *coordinates* (QPoint)"""
@@ -456,7 +448,7 @@ class BaseEditMixin(object):
         the line separator characters returned by :py:meth:`get_line_separator`
         """
         return str(self.textCursor().selectedText()).replace(
-            u"\u2029", self.get_line_separator()
+            "\u2029", self.get_line_separator()
         )
 
     def remove_selected_text(self):
@@ -486,7 +478,7 @@ class BaseEditMixin(object):
         text = str(self.toPlainText())
         try:
             regobj = re.compile(pattern)
-        except sre_constants.error:
+        except re.error:
             return
         if findflag & QTextDocument.FindBackward:
             # Find backward
@@ -538,7 +530,7 @@ class BaseEditMixin(object):
         else:
             text = re.escape(str(text))
 
-        pattern = QRegularExpression(u"\\b{}\\b".format(text) if words else text)
+        pattern = QRegularExpression("\\b{}\\b".format(text) if words else text)
         if case:
             pattern.setPatternOptions(QRegularExpression.CaseInsensitiveOption)
 
@@ -578,7 +570,7 @@ class BaseEditMixin(object):
                 regobj = re.compile(pattern)
             else:
                 regobj = re.compile(pattern, re.IGNORECASE)
-        except sre_constants.error:
+        except re.error:
             return None
 
         number_matches = 0
@@ -704,6 +696,7 @@ class GetHelpMixin(object):
                     arglist = self.get_arglist(text)
                     name = text.split(".")[-1]
                     argspec = signature = ""
+                    is_signature = True
                     if isinstance(arglist, bool):
                         arglist = []
                     if arglist:
@@ -717,13 +710,19 @@ class GetHelpMixin(object):
                             argspec = getargspecfromtext(doc)
                             if not argspec:
                                 signature = getsignaturefromtext(doc, name)
+                                if not signature:
+                                    signature = doc
+                                    is_signature = False
                     if argspec or signature:
                         if argspec:
                             tiptext = name + argspec
                         else:
                             tiptext = signature
                         self.show_calltip(
-                            _("Arguments"), tiptext, signature=True, color="#2D62FF"
+                            _("Arguments"),
+                            tiptext,
+                            signature=is_signature,
+                            color="#2D62FF",
                         )
 
     def get_last_obj(self, last=False):
