@@ -17,6 +17,8 @@ and the class DataFrameModel from the pandas project.
 Present in pandas.sandbox.qtpandas in v0.13.1.
 
 .. autoclass:: DataFrameEditor
+    :show-inheritance:
+    :members:
 
 Originally based on pandas/sandbox/qtpandas.py of the
 `pandas project <https://github.com/pandas-dev/pandas>`_.
@@ -27,8 +29,27 @@ The current version is qtpandas/models/DataFrameModel.py of the
 import io
 
 import numpy as np
-
 from pandas import DataFrame, DatetimeIndex, Series
+from qtpy.QtCore import QAbstractTableModel, QModelIndex, Qt, Signal, Slot
+from qtpy.QtGui import QColor, QCursor, QKeySequence
+from qtpy.QtWidgets import (
+    QAbstractItemView,
+    QApplication,
+    QCheckBox,
+    QDialog,
+    QGridLayout,
+    QHBoxLayout,
+    QHeaderView,
+    QInputDialog,
+    QLineEdit,
+    QMenu,
+    QMessageBox,
+    QPushButton,
+    QShortcut,
+    QTableView,
+)
+
+from guidata.config import CONF, _
 from guidata.configtools import get_font, get_icon
 from guidata.qthelpers import (
     add_actions,
@@ -36,35 +57,7 @@ from guidata.qthelpers import (
     keybinding,
     win32_fix_title_bar_background,
 )
-from guidata.config import CONF, _
-from qtpy.QtWidgets import (
-    QApplication,
-    QCheckBox,
-    QGridLayout,
-    QHBoxLayout,
-    QDialog,
-    QHeaderView,
-    QInputDialog,
-    QLineEdit,
-    QMenu,
-    QMessageBox,
-    QPushButton,
-    QTableView,
-    QShortcut,
-)
-from qtpy.QtGui import (
-    QKeySequence,
-    QColor,
-    QCursor,
-)
-from qtpy.QtCore import (
-    QAbstractTableModel,
-    QModelIndex,
-    Qt,
-    Signal,
-    Slot,
-)
-from guidata.widgets.arrayeditor import get_idx_rect
+from guidata.widgets.arrayeditor.utils import get_idx_rect
 
 try:
     from pandas._libs.tslib import OutOfBoundsDatetime
@@ -324,7 +317,7 @@ class DataFrameModel(QAbstractTableModel):
                         return str(value)
                     except Exception:
                         self.display_error_idxs.append(index)
-                        return u"Display Error!"
+                        return "Display Error!"
         elif role == Qt.BackgroundColorRole:
             return self.get_bgcolor(index)
         elif role == Qt.FontRole:
@@ -533,7 +526,7 @@ class FrozenTableView(QTableView):
         self.setVerticalScrollBarPolicy(Qt.ScrollBarAlwaysOff)
         self.show()
 
-        self.setVerticalScrollMode(1)
+        self.setVerticalScrollMode(QAbstractItemView.ScrollPerPixel)
 
     def update_geometry(self):
         """Update the frozen column size when an update occurs
@@ -556,8 +549,8 @@ class DataFrameView(QTableView):
         self.frozen_table_view = FrozenTableView(self)
         self.frozen_table_view.update_geometry()
 
-        self.setHorizontalScrollMode(1)
-        self.setVerticalScrollMode(1)
+        self.setHorizontalScrollMode(QAbstractItemView.ScrollPerPixel)
+        self.setVerticalScrollMode(QAbstractItemView.ScrollPerPixel)
 
         self.horizontalHeader().sectionResized.connect(self.update_section_width)
         self.verticalHeader().sectionResized.connect(self.update_section_height)
